============
Installation
============

At the command line::

    $ easy_install graphene_gae

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv graphene_gae
    $ pip install graphene_gae
